"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.LogamaticPlatform = void 0;
const heater_accessory_1 = require("./heater-accessory");
const water_accessory_1 = require("./water-accessory");
const km200_1 = require("./lib/km200");
class LogamaticPlatform {
    constructor(log, config, api) {
        this.log = log;
        this.hap = api.hap;
        this.config = config;
        this.km200 = new km200_1.KM200();
        this.km200.init(this.config.url, this.config.gatewayPassword, this.config.privatePassword);
        log.info('Logamatic finished initializing!');
    }
    /*
     * This method is called to retrieve all accessories exposed by the platform.
     * The Platform can delay the response my invoking the callback at a later time,
     * it will delay the bridge startup though, so keep it to a minimum.
     * The set of exposed accessories CANNOT change over the lifetime of the plugin!
     */
    accessories(callback) {
        this.km200.get('system/healthStatus')
            .then(logamaticConfiguration => {
            callback([
                new heater_accessory_1.LogamaticHeater(this.hap, this.log, 'Heater', this.config, logamaticConfiguration, this.km200),
                new water_accessory_1.LogamaticWater(this.hap, this.log, 'Water Boiler', this.config, logamaticConfiguration, this.km200),
            ]);
        })
            .catch(e => {
            this.log.error(e);
        });
    }
}
exports.LogamaticPlatform = LogamaticPlatform;
//# sourceMappingURL=platform.js.map